# [[file:phoenix.org::*Mix Configuration (\[\[./mix.exs\]\])][Mix Configuration ([[./mix.exs]]):1]]
defmodule Arcology.MixProject do
  use Mix.Project

  def project do
    [
      app: :arcology,
      version: "0.1.0",
      elixir: "~> 1.7",
      elixirc_paths: elixirc_paths(Mix.env()),
      compilers: [:phoenix, :gettext] ++ Mix.compilers(),
      start_permanent: Mix.env() == :prod,
      aliases: aliases(),
      deps: deps()
    ]
  end

  def application do
    [
      mod: {Arcology.Application, []},
      extra_applications: [:logger, :runtime_tools]
    ]
  end

  defp deps do
    [
      {:distillery, "~> 2.0"},
      {:sqlite_ecto2, "~> 2.2"},
      {:symbolic_expression,
       git: "https://github.com/rob-brown/SymbolicExpression", tag: "1.0.3"},
      {:panpipe, "~> 0.1"},
      {:phoenix, "~> 1.4.10"},
      {:phoenix_pubsub, "~> 1.1"},
      {:phoenix_html, "~> 2.11"},
      {:phoenix_live_reload, "~> 1.2", only: :dev},
      {:gettext, "~> 0.11"},
      {:jason, "~> 1.0"},
      {:plug_cowboy, "~> 2.0"},
      {:memoize, "~>1.3"},
      {:mix_test_watch, "~> 1.0", only: :dev, runtime: false},
      {:file_system, "~> 0.2"},
      {:rebar3_hex, "~> 6.0"}
    ]
  end

  defp aliases do
    [
      "ecto.setup": ["ecto.create", "ecto.migrate", "run priv/repo/seeds.exs"],
      "ecto.reset": ["ecto.drop", "ecto.setup"],
      test: ["arcology.build", "test"]
    ]
  end

  defp elixirc_paths(:test), do: ["lib", "test/support"]
  defp elixirc_paths(_), do: ["lib"]
end

# Mix Configuration ([[./mix.exs]]):1 ends here
